@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.033-12-g97b012c
-$Test::Moose::More::VERSION = '0.034'; # TRIAL
+# git description: 0.035-4-g75693a2
+$Test::Moose::More::VERSION = '0.036'; # TRIAL
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -143,10 +143,7 @@ sub _find_attribute {
 sub has_attribute_ok ($$;$) {
     my ($thing, $attr_name, $message) = @_;
 
-    my $meta       = find_meta($thing);
-    my $thing_name = $meta->name;
-    $message     ||= "$thing_name has an attribute named $attr_name";
-
+    $message ||= _thing_name($thing) . " has an attribute named $attr_name";
     return $tb->ok(!!_find_attribute($thing => $attr_name), $message);
 }
 
@@ -202,24 +199,24 @@ sub requires_method_ok {
 }
 
 
-sub is_immutable_ok {
-    my ($thing) = @_;
+sub is_immutable_ok($;$) {
+    my ($thing, $message) = @_;
 
     ### $thing
     my $meta = find_meta($thing);
-    my $name = $meta->name;
 
-    return $tb->ok($meta->is_immutable, "$name is immutable");
+    $message ||= _thing_name($thing, $meta) . ' is immutable';
+    return $tb->ok($meta->is_immutable, $message);
 }
 
-sub is_not_immutable_ok {
-    my ($thing) = @_;
+sub is_not_immutable_ok($;$) {
+    my ($thing, $message) = @_;
 
     ### $thing
     my $meta = find_meta($thing);
-    my $name = $meta->name;
 
-    return $tb->ok(!$meta->is_immutable, "$name is not immutable");
+    $message ||= _thing_name($thing, $meta) . ' is not immutable';
+    return $tb->ok(!$meta->is_immutable, $message);
 }
 
 
@@ -233,7 +230,7 @@ sub is_class_ok { unshift @_, 'Class'; goto \&_is_moosey_ok }
 sub _is_moosey_ok {
     my ($type, $thing) =  @_;
 
-    my $thing_name = ref $thing || $thing;
+    my $thing_name = _thing_name($thing);
 
     my $meta = find_meta($thing);
     $tb->ok(!!$meta, "$thing_name has a metaclass");
@@ -343,7 +340,7 @@ sub _validate_thing_guts {
                 skip 'Cannot examine attribute metaclass in roles', 1
                     if (find_meta($thing)->isa('Moose::Meta::Role'));
 
-                local $THING_NAME = "${thing}'s attribute $name";
+                local $THING_NAME = _thing_name($thing) . "'s attribute $name";
                 _validate_attribute($att => (
                     -subtest => "checking $THING_NAME",
                     %$opts,
@@ -385,8 +382,17 @@ sub _validate_role_guts {
 
     # basic role validation
     return unless is_role_ok $role;
+
     requires_method_ok($role => @{ $args{required_methods} })
         if defined $args{required_methods};
+
+    role_wraps_before_method_ok($role => @{ $args{before} })
+        if defined $args{before};
+    role_wraps_around_method_ok($role => @{ $args{around} })
+        if defined $args{around};
+    role_wraps_after_method_ok($role => @{ $args{after} })
+        if defined $args{after};
+
     $args{-compose}
         ?        validate_thing $role => %args
         : return validate_thing $role => %args
@@ -601,7 +607,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.034 of Test::Moose::More - released July 29, 2015 as part of Test-Moose-More.
+This document describes version 0.036 of Test::Moose::More - released January 20, 2016 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -858,6 +864,30 @@ required_methods => [ ... ]
 
 A list of methods the role requires a consuming class to supply.
 
+=item *
+
+before => [ ... ]
+
+A list of methods the role expects to wrap before, on application to a class.
+
+See L<Moose/before> for information on before method modifiers.
+
+=item *
+
+around => [ ... ]
+
+A list of methods the role expects to wrap around, on application to a class.
+
+See L<Moose/around> for information on around method modifiers.
+
+=item *
+
+after => [ ... ]
+
+A list of methods the role expects to wrap after, on application to a class.
+
+See L<Moose/after> for information on after method modifiers.
+
 =back
 
 =head2 validate_class
